//
//  ContentListViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/08/11.
//

import Foundation
import Combine

final class ContentListViewModel: ObservableObject {
    
    enum Sort: String {
        case NEWEST, PRICE_HIGH, PRICE_LOW
    }
    
    private let repository = ContentRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var audioContentList: [GetAudioContentListItem] = []
    @Published var totalCount = 0
    @Published var sort = Sort.NEWEST {
        didSet {
            page = 1
            isLast = false
            getAudioContentList()
        }
    }
    
    @Published var scrollToTop = false
    
    var userId = 0
    var page = 1
    var isLast = false
    private let pageSize = 10
    
    func getAudioContentList() {
        if (!isLast && !isLoading) {
            isLoading = true
            
            repository
                .getAudioContentList(userId: userId, page: page, size: pageSize, sort: sort)
                .sink { result in
                    switch result {
                    case .finished:
                        DEBUG_LOG("finish")
                    case .failure(let error):
                        ERROR_LOG(error.localizedDescription)
                    }
                } receiveValue: { [unowned self] response in
                    let responseData = response.data
                    
                    do {
                        let jsonDecoder = JSONDecoder()
                        let decoded = try jsonDecoder.decode(ApiResponse<GetAudioContentListResponse>.self, from: responseData)
                        
                        if let data = decoded.data, decoded.success {
                            if page == 1 {
                                self.audioContentList.removeAll()
                                self.scrollToTop.toggle()
                            }
                            
                            if !data.items.isEmpty {
                                page += 1
                                self.totalCount = data.totalCount
                                self.audioContentList.append(contentsOf: data.items)
                            } else {
                                isLast = true
                            }
                        } else {
                            if let message = decoded.message {
                                self.errorMessage = message
                            } else {
                                self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                            }
                            
                            self.isShowPopup = true
                        }
                    } catch {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        self.isShowPopup = true
                    }
                    
                    self.isLoading = false
                }
                .store(in: &subscription)
        }
    }
}
